@@ -18,7 +18,7 @@ class Formatter(object):
         super(Formatter, self).__init__()
         self._origin = (0, 0) # cursor position where we put the upper left pixel
 
-    def format(self, image, dispose=None):
+    def format(self, frame):
         """
         Convert image to a string and return it. Get background color
         from dispose for transparent pixels.
@@ -63,3 +63,12 @@ class Formatter(object):
         area.
         """
         raise NotImplementedError()
+
+
+    @classmethod
+    def color_code(cls, r, g, b, a=255):
+        """
+        Convert the given color into the colorspace used by the
+        formatter.
+        """
+        raise NotImplementedError()
